MyLogMixin mixin

Mixin applications

Properties

dateFormatYMD → DateFormat
no setter
hashCode int
The hash code for this object.
no setterinherited
logFile String?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() Future<void>
flush() Future<void>
getLevel() → Level
getLogFile(bool debug, {int days = 3, String? pathStart}) Future<String>
getLogger({String? name}) → Logger
init({bool debug = false, int days = 3, String? pathStart}) Future<Logger>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
prettyJson(dynamic data) String
setLevel(Level level) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited